@@ -31,7 +31,7 @@ class AsyncRSAP:
             plan(str, optional): The plan, if any, that you have subscribed to.
         """
         self.key = api_key,
-        if self.api_key == "":
+        if self.key == "":
             raise InvalidKey(
                 "The API key you provided is not a valid one. Please recheck it")
         self.dev = kwargs.get("dev_name", "Hunter"),
@@ -39,13 +39,13 @@ class AsyncRSAP:
         self.type = kwargs.get("type", "stable"),
         self.language = kwargs.get("language", "en")
         self.plan = kwargs.get("plan", None)
+        self.plans = ("pro", "ultra", "biz", "mega")
         if self.plan not in self.plans and self.plan is not None:
             raise InvalidArgument(
                 "The plan you mentioned is not valid")
-        if self.plan in self._plans:
+        if self.plan in self.plans:
             pass
         self.headers = {"x-api-key": self.key[0]}
-        self._plans = ("pro", "ultra", "biz", "mega")
         self._jokes_types = ("any", "dev", "spooky", "pun")
         self._image_types = ("aww", "duck", "dog", "cat", "memes",
                              "dankmemes", "holup", "art", "harrypottermemes", "facepalm")
